@@ -648,7 +648,7 @@ void MainWindow::buttonHelp_clicked()
     QLocale locale;
     const QString lang = locale.bcp47Name();
 
-    QString url("/usr/share/doc/bootrepair/boot-repair.html");
+    QString url("/usr/share/doc/bootrepair/bootrepair.html");
     if (lang.startsWith(QLatin1String("fr"))) {
         url = "https://mxlinux.org/wiki/help-files/help-r%C3%A9paration-d%E2%80%99amor%C3%A7age";
     }
