@@ -1,242 +1,209 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="mainwindow.ui" line="20"/>
-        <location filename="ui_mainwindow.h" line="392"/>
-        <source>Boot Repair</source>
-        <translation>Reparador de Inicialização</translation>
+        <location filename="../mainwindow.ui" line="20"/>
+        <source>MX Boot Repair</source>
+        <translation>Reparador de Inicialização do MX</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="39"/>
-        <location filename="ui_mainwindow.h" line="393"/>
-        <source>Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
-        <translation>O Reparador de Inicialização (Boot Repair) é um utilitário que pode ser usado para reinstalar ou reparar o gerenciador/carregador do inicialização GRUB na ESP (EFI System Partition), no MBR (Master Boot Record) ou na partição raiz (/,root). Ele fornece as opções de reconstruir o arquivo de configuração do GRUB, fazer cópia de segurança e restaurar o MBR ou o PBR (root).</translation>
+        <location filename="../mainwindow.ui" line="39"/>
+        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
+        <translation>O Reparador de Inicialização do MX (MX Boot Repair) é um utilitário que pode ser utilizado para reinstalar ou reparar o gerenciador/carregador de inicialização GRUB na ESP (EFI System Partition), no MBR (Master Boot Record) ou na partição raiz ( /, root). O reparador fornece as opções de reconstruir o arquivo de configuração do GRUB, fazer cópia de segurança e restaurar o MBR ou o PBR (root).</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="58"/>
-        <location filename="ui_mainwindow.h" line="394"/>
+        <location filename="../mainwindow.ui" line="58"/>
         <source>What would you like to do?</source>
         <translation>O que você pretende fazer?</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="79"/>
-        <location filename="ui_mainwindow.h" line="395"/>
+        <location filename="../mainwindow.ui" line="79"/>
         <source>Backup MBR or PBR (legacy boot only)</source>
         <translation>Cópia de segurança do MBR ou do PBR (apenas em computadores com BIOS)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="86"/>
-        <location filename="ui_mainwindow.h" line="396"/>
+        <location filename="../mainwindow.ui" line="86"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
-        <translation>Reinstalar o gerenciador/carregador de inicialização GRUB em ESP, MBR ou PBR (root)</translation>
+        <translation>Reinstalar o gerenciador/carregador de inicialização GRUB em uma partição ESP, MBR ou PBR (root)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="96"/>
-        <location filename="ui_mainwindow.h" line="397"/>
+        <location filename="../mainwindow.ui" line="96"/>
         <source>Repair GRUB configuration file</source>
         <translation>Reparar o arquivo de configuração do GRUB</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="103"/>
-        <location filename="ui_mainwindow.h" line="398"/>
+        <location filename="../mainwindow.ui" line="103"/>
         <source>Restore MBR or PBR from backup (legacy boot only)</source>
         <translation>Restaurar MBR ou PBR a partir da cópia (apenas em computadores com BIOS)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="136"/>
-        <location filename="mainwindow.cpp" line="483"/>
-        <location filename="ui_mainwindow.h" line="399"/>
+        <location filename="../mainwindow.ui" line="136"/>
+        <location filename="../mainwindow.cpp" line="561"/>
         <source>Select Boot Method</source>
         <translation>Selecionar o Método de Inicialização</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="154"/>
-        <location filename="ui_mainwindow.h" line="401"/>
+        <location filename="../mainwindow.ui" line="154"/>
         <source>Master Boot Record</source>
         <translation>Master Boot Record (Registro Mestre de Inicialização)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="157"/>
-        <location filename="ui_mainwindow.h" line="403"/>
+        <location filename="../mainwindow.ui" line="157"/>
         <source>MBR</source>
         <translation>MBR</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="160"/>
-        <location filename="mainwindow.ui" line="430"/>
-        <location filename="ui_mainwindow.h" line="405"/>
-        <location filename="ui_mainwindow.h" line="426"/>
+        <location filename="../mainwindow.ui" line="160"/>
+        <location filename="../mainwindow.ui" line="430"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="182"/>
-        <location filename="ui_mainwindow.h" line="408"/>
+        <location filename="../mainwindow.ui" line="182"/>
         <source>Root (Partition Boot Record)</source>
         <translation>Root (Partition Boot Record - Registro da Partição de Inicialização)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="185"/>
-        <location filename="mainwindow.cpp" line="486"/>
-        <location filename="ui_mainwindow.h" line="410"/>
+        <location filename="../mainwindow.ui" line="185"/>
+        <location filename="../mainwindow.cpp" line="564"/>
         <source>root</source>
         <translation>raiz (PBR)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="236"/>
-        <location filename="mainwindow.cpp" line="485"/>
-        <location filename="ui_mainwindow.h" line="411"/>
+        <location filename="../mainwindow.ui" line="236"/>
+        <location filename="../mainwindow.cpp" line="563"/>
         <source>Install on:</source>
         <translation>Instalar em:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="255"/>
-        <location filename="mainwindow.cpp" line="484"/>
-        <location filename="ui_mainwindow.h" line="412"/>
+        <location filename="../mainwindow.ui" line="255"/>
+        <location filename="../mainwindow.cpp" line="562"/>
         <source>Location:</source>
         <translation>Localização:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="277"/>
-        <location filename="mainwindow.cpp" line="494"/>
-        <location filename="ui_mainwindow.h" line="416"/>
+        <location filename="../mainwindow.ui" line="277"/>
+        <location filename="../mainwindow.cpp" line="572"/>
         <source>Select root location:</source>
-        <translation>Selecionar a localização da raiz ( / , root):</translation>
+        <translation>Selecionar a localização da raiz ( /, root):</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="290"/>
-        <location filename="ui_mainwindow.h" line="418"/>
+        <location filename="../mainwindow.ui" line="290"/>
         <source>EFI System Partition</source>
         <translation>Partição de Sistema EFI</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="293"/>
-        <location filename="ui_mainwindow.h" line="420"/>
+        <location filename="../mainwindow.ui" line="293"/>
         <source>ESP</source>
         <translation>ESP</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="420"/>
-        <location filename="ui_mainwindow.h" line="422"/>
+        <location filename="../mainwindow.ui" line="420"/>
         <source>About this application</source>
         <translation>Sobre este aplicativo</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="423"/>
-        <location filename="ui_mainwindow.h" line="424"/>
+        <location filename="../mainwindow.ui" line="423"/>
         <source>About...</source>
         <translation>Sobre...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="472"/>
-        <location filename="ui_mainwindow.h" line="429"/>
+        <location filename="../mainwindow.ui" line="472"/>
         <source>Display help </source>
         <translation>Exibir ajuda</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="475"/>
-        <location filename="ui_mainwindow.h" line="431"/>
+        <location filename="../mainwindow.ui" line="475"/>
         <source>Help</source>
         <translation>Ajuda</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="482"/>
-        <location filename="ui_mainwindow.h" line="433"/>
+        <location filename="../mainwindow.ui" line="482"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="523"/>
-        <location filename="ui_mainwindow.h" line="437"/>
+        <location filename="../mainwindow.ui" line="523"/>
         <source>Cancel any changes then quit</source>
-        <translation>Cancelar alterações e sair</translation>
+        <translation>Cancelar as alterações e sair</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="526"/>
-        <location filename="ui_mainwindow.h" line="439"/>
+        <location filename="../mainwindow.ui" line="526"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="533"/>
-        <location filename="ui_mainwindow.h" line="441"/>
+        <location filename="../mainwindow.ui" line="533"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="552"/>
-        <location filename="ui_mainwindow.h" line="444"/>
+        <location filename="../mainwindow.ui" line="552"/>
         <source>Apply any changes</source>
-        <translation>Aplicar alterações</translation>
+        <translation>Aplicar as alterações</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="555"/>
-        <location filename="mainwindow.cpp" line="71"/>
-        <location filename="ui_mainwindow.h" line="446"/>
+        <location filename="../mainwindow.ui" line="555"/>
+        <location filename="../mainwindow.cpp" line="93"/>
         <source>Apply</source>
         <translation>Aplicar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="87"/>
+        <location filename="../mainwindow.cpp" line="109"/>
         <source>GRUB is being installed on %1 device.</source>
         <translation>O GRUB está sendo instalado em %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="110"/>
-        <location filename="mainwindow.cpp" line="130"/>
-        <location filename="mainwindow.cpp" line="192"/>
-        <location filename="mainwindow.cpp" line="216"/>
-        <location filename="mainwindow.cpp" line="322"/>
-        <location filename="mainwindow.cpp" line="396"/>
-        <location filename="mainwindow.cpp" line="419"/>
-        <location filename="mainwindow.cpp" line="525"/>
-        <location filename="mainwindow.cpp" line="532"/>
-        <location filename="mainwindow.cpp" line="591"/>
+        <location filename="../mainwindow.cpp" line="148"/>
+        <location filename="../mainwindow.cpp" line="233"/>
+        <location filename="../mainwindow.cpp" line="358"/>
+        <location filename="../mainwindow.cpp" line="456"/>
+        <location filename="../mainwindow.cpp" line="495"/>
+        <location filename="../mainwindow.cpp" line="600"/>
+        <location filename="../mainwindow.cpp" line="604"/>
+        <location filename="../mainwindow.cpp" line="612"/>
+        <location filename="../mainwindow.cpp" line="619"/>
+        <location filename="../mainwindow.cpp" line="625"/>
+        <location filename="../mainwindow.cpp" line="678"/>
+        <location filename="../mainwindow.cpp" line="689"/>
         <source>Error</source>
         <translation>Erro</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="110"/>
-        <location filename="mainwindow.cpp" line="192"/>
-        <source>Could not create a temporary folder</source>
-        <translation>Não foi possível criar uma pasta temporária</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="130"/>
-        <location filename="mainwindow.cpp" line="216"/>
+        <location filename="../mainwindow.cpp" line="149"/>
+        <location filename="../mainwindow.cpp" line="234"/>
         <source>Could not set up chroot environment.
 Please double-check the selected location.</source>
         <translation>Não foi possível configurar o ambiente chroot.
 Por favor, verifique novamente o local selecionado.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="189"/>
+        <location filename="../mainwindow.cpp" line="214"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
         <translation>O arquivo de configuração do GRUB (grub.cfg) está sendo reconstruído.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="233"/>
+        <location filename="../mainwindow.cpp" line="251"/>
         <source>Backing up MBR or PBR from %1 device.</source>
-        <translation>Fazendo cópia de segurança do MBR ou do PBR do dispositivo %1</translation>
+        <translation>Fazendo a cópia de segurança do MBR ou do PBR do dispositivo %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="297"/>
+        <location filename="../mainwindow.cpp" line="330"/>
         <source>Warning</source>
         <translation>Aviso</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="298"/>
+        <location filename="../mainwindow.cpp" line="331"/>
         <source>You are going to write the content of </source>
         <translation>Você vai escrever o conteúdo de </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="298"/>
+        <location filename="../mainwindow.cpp" line="331"/>
         <source> to </source>
         <translation> em </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="298"/>
+        <location filename="../mainwindow.cpp" line="332"/>
         <source>
 
 Are you sure?</source>
@@ -245,152 +212,170 @@ Are you sure?</source>
 Você tem certeza?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="303"/>
+        <location filename="../mainwindow.cpp" line="338"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
         <translation>Restaurando MBR/PBR para o dispositivo %1 a partir da cópia de segurança.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="322"/>
+        <location filename="../mainwindow.cpp" line="359"/>
         <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
         <translation>Não foi possível encontrar a partição ESP (EFI System Partition) em qualquer dos discos do sistema. Crie uma ESP e tente novamente.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="353"/>
+        <location filename="../mainwindow.cpp" line="402"/>
         <source>Select %1 location:</source>
         <translation>Selecionar a localização de %1:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="375"/>
+        <location filename="../mainwindow.cpp" line="433"/>
         <source>Back</source>
         <translation>Voltar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="391"/>
+        <location filename="../mainwindow.cpp" line="450"/>
         <source>Success</source>
         <translation>Sucesso</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="392"/>
-        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit Boot Repair?&lt;/b&gt;</source>
-        <translation>O processo foi concluído com sucesso.&lt;p&gt;&lt;b&gt;Você deseja sair do Reparador de Inicialização (Boot Repair)?&lt;/b&gt;</translation>
+        <location filename="../mainwindow.cpp" line="450"/>
+        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
+        <translation>O processo foi concluído com sucesso.&lt;p&gt;&lt;b&gt;Você quer sair do Reparador de Inicialização do MX (MX Boot Repair)?&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="396"/>
+        <location filename="../mainwindow.cpp" line="456"/>
         <source>Process finished. Errors have occurred.</source>
         <translation>O processo foi concluído. Ocorreram erros.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="413"/>
+        <location filename="../mainwindow.cpp" line="484"/>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>Inserir a senha para desbloquear a partição criptografada/encriptada %1:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="419"/>
+        <location filename="../mainwindow.cpp" line="495"/>
         <source>Sorry, could not open %1 LUKS container</source>
         <translation>Desculpe, não foi possível abrir o contêiner %1 LUKS</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="493"/>
+        <location filename="../mainwindow.cpp" line="571"/>
         <source>Select GRUB location</source>
         <translation>Selecione a localização do GRUB</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="505"/>
+        <location filename="../mainwindow.cpp" line="583"/>
         <source>Select Item to Back Up</source>
         <translation>Selecione o item para fazer a cópia de segurança</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="512"/>
+        <location filename="../mainwindow.cpp" line="590"/>
         <source>Select Item to Restore</source>
         <translation>Selecione o item para restaurar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="523"/>
+        <location filename="../mainwindow.cpp" line="600"/>
+        <location filename="../mainwindow.cpp" line="625"/>
+        <source>No location was selected.</source>
+        <translation>Nenhum local foi selecionado.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="605"/>
+        <source>Please select the root partition of the system you want to fix.</source>
+        <translation>Por favor, selecione a partição de root (raiz) do sistema que você deseja corrigir.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="610"/>
         <source>Select backup file name</source>
         <translation>Escolha o nome do arquivo da cópia de segurança (backup).</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="525"/>
-        <location filename="mainwindow.cpp" line="532"/>
+        <location filename="../mainwindow.cpp" line="612"/>
+        <location filename="../mainwindow.cpp" line="619"/>
         <source>No file was selected.</source>
         <translation>Nenhum arquivo foi selecionado.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="530"/>
+        <location filename="../mainwindow.cpp" line="617"/>
         <source>Select MBR or PBR backup file</source>
         <translation>Selecione o arquivo da cópia de segurança (backup) MBR ou PBR</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="550"/>
+        <location filename="../mainwindow.cpp" line="642"/>
         <source>About %1</source>
         <translation>Sobre o %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="551"/>
+        <location filename="../mainwindow.cpp" line="644"/>
         <source>Version: </source>
         <translation>Versão: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="552"/>
-        <source>Simple boot repair program for antiX Linux</source>
-        <translation>Programa simples de reparo de inicialização (boot) para antiX Linux</translation>
+        <location filename="../mainwindow.cpp" line="645"/>
+        <source>Simple boot repair program for MX Linux</source>
+        <translation>Programa simples de reparo de inicialização (boot) para MX Linux.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="554"/>
+        <location filename="../mainwindow.cpp" line="647"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Direitos de Autor (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="555"/>
+        <location filename="../mainwindow.cpp" line="648"/>
         <source>%1 License</source>
         <translation>Licença do %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="568"/>
+        <location filename="../mainwindow.cpp" line="661"/>
         <source>%1 Help</source>
         <translation>Ajuda do %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="591"/>
+        <location filename="../mainwindow.cpp" line="678"/>
         <source>Sorry, could not mount %1 partition</source>
         <translation>Desculpe, não foi possível montar a partição %1</translation>
     </message>
-</context>
-<context>
-    <name>QApplication</name>
     <message>
-        <location filename="about.cpp" line="32"/>
-        <source>License</source>
-        <translation>Licença</translation>
-    </message>
-    <message>
-        <location filename="about.cpp" line="33"/>
-        <location filename="about.cpp" line="43"/>
-        <source>Changelog</source>
-        <translation>Relatório de alterações</translation>
-    </message>
-    <message>
-        <location filename="about.cpp" line="34"/>
-        <source>Cancel</source>
-        <translation>Cancelar</translation>
-    </message>
-    <message>
-        <location filename="about.cpp" line="51"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Fechar</translation>
+        <location filename="../mainwindow.cpp" line="689"/>
+        <source>Could not create a temporary folder</source>
+        <translation>Não foi possível criar uma pasta temporária</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="main.cpp" line="57"/>
-        <source>Error</source>
-        <translation>Erro</translation>
+        <location filename="../about.cpp" line="52"/>
+        <source>License</source>
+        <translation>Licença</translation>
     </message>
     <message>
-        <location filename="main.cpp" line="58"/>
-        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
-        <translation>Parece que você está conectado como root, por favor saia da sessão e entre novamente como usuário normal para usar este programa.</translation>
+        <location filename="../about.cpp" line="53"/>
+        <location filename="../about.cpp" line="63"/>
+        <source>Changelog</source>
+        <translation>Relatório de Alterações</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="54"/>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="73"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Fechar</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="53"/>
+        <source>MX Boot Repair</source>
+        <translation>Reparador de Inicialização do MX</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="86"/>
+        <source>Error</source>
+        <translation>Ocorreu um Erro</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="87"/>
+        <source>You must run this program with admin access.</source>
+        <translation>Você tem que executar este programa com o usuário administrador.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
